# miniscope-io

[![PyPI - Version](https://img.shields.io/pypi/v/miniscope-io)](https://pypi.org/project/miniscope_io/)
[![Documentation Status](https://readthedocs.org/projects/miniscope-io/badge/?version=latest)](https://miniscope-io.readthedocs.io/en/latest/?badge=latest)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/miniscope-io)
![PyPI - Status](https://img.shields.io/pypi/status/miniscope-io)
[![Coverage Status](https://coveralls.io/repos/github/Aharoni-Lab/miniscope-io/badge.svg?branch=main)](https://coveralls.io/github/Aharoni-Lab/miniscope-io?branch=main)

Generic i/o interfaces for miniscopes.

In alpha - Fuller README forthcoming.

See the docs for now: https://miniscope-io.readthedocs.io/



## Licensing

This package includes software sublicensed from more 
restrictive licenses. Those licenses can be found
in the `LICENSE` files in the respective directories 
containing the unmodified source material

* `miniscope_io/vendor/opalkelly` 